{% extends "wagtailadmin/widgets/chooser.html" %}

{% block chooser_class %}poll-chooser{% endblock %}

{% block chosen_state_view %}
    <span class="title">{{ item }}</span>
{% endblock %}

{% block edit_chosen_item_url %}{% url 'wagtailpolls_edit' poll_pk=item.pk %}{% endblock %}
