{% load i18n %}
{% trans "Choose a" as choose_str %}
{% include "wagtailadmin/shared/header.html" with title=choose_str subtitle=snippet_type_name icon="group" %}

<div class="nice-padding">
	{# Need to keep the form in the HTML, even if the snippet is not searchable #}
	{# This is to allow pagination links to be generated from the form action URL #}
	<form class="snippet-search search-bar" action="{% url 'wagtailpolls_choose' %}" method="GET">
		{% if is_searchable %}
			<ul class="fields">
				{% for field in search_form %}
					{% include "wagtailadmin/shared/field_as_li.html" with field=field %}
				{% endfor %}
				<li class="submit"><input type="submit" value="{% trans 'Search' %}" /></li>
			</ul>
		{% endif %}
	</form>

	<div id="search-results" class="listing snippets">
		{% include "wagtailpolls/results.html" with choosing=1 %}
	</div>
</div>
