{% load i18n %}
<table class="listing">
	<col />
	<col  />
	<col width="16%" />
	<thead>
		<tr class="table-headers">
			<th>{% trans "Title" %}</th>
		</tr>
	</thead>
	<tbody>
		{% for snippet in items %}
			<tr>
				<td class="title">
					{% if choosing %}
						<h2><a class="snippet-choice" href="{% url 'wagtailpolls_choosen' snippet.id %}">{{ snippet }}</a></h2>
					{% else %}
						<h2><a href="{% url 'wagtailpolls_choose' snippet.id %}">{{ snippet }}</a></h2>
					{% endif %}
				</td>
			</tr>
		{% endfor %}
	</tbody>
</table>
