{% extends "wagtailadmin/base.html" %}
{% load i18n %}
{% block titletag %}{% trans "Polls" %}{% endblock %}
{% block bodyclass %}menu-poll{% endblock %}
{% block content %}

	{% trans "Copy" as new_str %}
	{% include "wagtailadmin/shared/header.html" with title=new_str subtitle=poll icon="grip" %}

	<div class="row row-flush nice-padding">
		<form action="{% url 'wagtailpolls_copy' poll_pk=poll.pk %}" method="POST">
			{% csrf_token %}
			<p>{% blocktrans %}Are you sure you want to create a duplicate of this poll?{% endblocktrans %}</p>
			<input type="submit" class="button yes" value="{% trans 'Yes, create duplicate' %}" />
		</form>
	</div>
{% endblock %}

{% block extra_css %}
	{% include "wagtailadmin/pages/_editor_css.html" %}
{% endblock %}
{% block extra_js %}
	{% include "wagtailadmin/pages/_editor_js.html" %}
{% endblock %}
